@@ -43,7 +43,7 @@ annotatemsbatch <- function(msbatch,
                                                 "PCp", "PE", "PEo", "PEp", "PG",
                                                 "PI", "Sph", "SphP", "Cer", 
                                                 "CerP", "AcylCer", "SM", 
-                                                "Carnitine", "CE", "DG", "TG"),
+                                                "Carnitines", "CE", "DG", "TG"),
                             lipidClassesNeg = c("FA", "FAHFA", "LPC", "LPE", 
                                                 "LPG", "LPI", "LPS", "PC", "PCo", 
                                                 "PCp", "PE", "PEo", "PEp", "PG", 
